Custom styles for PyRemoteData documentation

/* Improve current page highlighting in navigation */
.wy-menu-vertical li.current > a {
    background-color: #1976d2 !important;
    color: white !important;
}

.wy-menu-vertical li.current > a:hover {
    background-color: #1565c0 !important;
}

/* Highlight current section */
.wy-menu-vertical li.current > a::before {
    content: "▶ ";
    color: white;
}

/* Improve sidebar navigation */
.wy-nav-side { background-color: #f8f9fa; }
.wy-menu-vertical { background-color: #f8f9fa; }

/* Better spacing for main content */
.wy-nav-content-wrap { margin-left: 300px; }

[data-md-color-primary=blue] .md-typeset a.toc-backref {
    color: rgba(0, 0, 0, .54);
}

/* Improve code block appearance */
.highlight {
    background-color: #f5f5f5;
    border-radius: 4px;
}

/* Better table styling */
.wy-table-responsive table { border-collapse: collapse; width: 100%; }
.wy-table-responsive th,
.wy-table-responsive td { border: 1px solid #ddd; padding: 8px; text-align: left; }
.wy-table-responsive th { background-color: #f2f2f2; font-weight: bold; }

/* Better section headers */
h1, h2, h3, h4, h5, h6 { color: #333; margin-top: 1.5em; margin-bottom: 0.5em; }

/* Improve list spacing */
ul, ol { margin-bottom: 1em; }
li { margin-bottom: 0.25em; }

/* ------------------------------ */
/* Signature (function/class) styling */
/* ------------------------------ */

/* Box styling for signatures */
span.sphinx_autodoc_typehints-type, .sig, .desc.signature {
    padding: 0 0.3em;
    border: 1px solid #e1e4e8;
    border-radius: 6px;
    font-family: var(--font-monospace, SFMono-Regular, Consolas, Menlo, monospace);
    background: #f6f8fa;
}

.sig, .desc.signature {
    padding: 0.6em 0.8em;
    margin: 0.75em 0 0.5em 0;
    box-shadow: 0 1px 2px rgba(0,0,0,.04);
    white-space: normal;           /* allow normal wrapping */
    overflow-wrap: anywhere;       /* break long tokens if needed */
}

/* Name coloring (class/function) */
.sig .sig-name, .descname {
    color: #005cc5;
    font-weight: 600;
}

/* Module/qualifier coloring */
.sig .sig-prename, .sig .sig-name .pre { color: #6a737d; }

/* Keyword (e.g., class/def) */
.sig .sig-prefix, .sig .sig-keyword { color: #d73a49; font-weight: 600; }

/* Parameters each on their own line */
.sig .sig-param { color: #24292e; }



/* Keep source link visible but muted */
.sig .viewcode-link { color: #dd3d3d; font-weight: bold; }

/* HACK */
dt:target {
    margin-top: unset !important;
    padding-top: 0.35rem !important;
}

.md-typeset dl.api-field {
    padding: 0.5em;
    p {
        margin: unset;
    }
    dd {
        margin-top: 0;
        margin-bottom: 0;
    }
    dd:has(+ dt) {
        margin-bottom: 0.75em;
    }
    dt, dt code {
        font-size: 0.75rem;
    }
}

.md-typeset dl.field-list > dd {
    margin: unset;
}

.md-grid {
    max-width: 80rem;
}

.md-nav__link {
    gap: 0;
}

.md-nav__link > span.objinfo-icon {
    color: transparent;
    content: "";
    border-radius: 50%;
    width: 18px;
}

nav.md-nav nav.md-nav nav.md-nav {
    display: none;
}